@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#endif
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
@@ -36,35 +34,17 @@
 
 #include "xmlstyli.hxx"
 #include "document.hxx"
-#ifndef _SC_XMLCONVERTER_HXX
 #include "XMLConverter.hxx"
-#endif
-#ifndef SC_DOCUNO_HXX
 #include "docuno.hxx"
-#endif
-#ifndef _SC_XMLSTYLESIMPORTHELPER_HXX
 #include "XMLStylesImportHelper.hxx"
-#endif
 
-#ifndef _XMLOFF_XMLUCONV_HXX
 #include <bf_xmloff/xmluconv.hxx>
-#endif
-#ifndef _XMLOFF_XMLERROR_HXX
 #include <bf_xmloff/xmlerror.hxx>
-#endif
 
-#ifndef _COM_SUN_STAR_UTIL_XMERGEABLE_HPP_
 #include <com/sun/star/util/XMergeable.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SHEET_XCELLRANGEADDRESSABLE_HPP_
 #include <com/sun/star/sheet/XCellRangeAddressable.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SHEET_XCELLRANGEMOVEMENT_HPP_
 #include <com/sun/star/sheet/XCellRangeMovement.hpp>
-#endif
-#ifndef _COM_SUN_STAR_DRAWING_XDRAWPAGESUPPLIER_HPP_
 #include <com/sun/star/drawing/XDrawPageSupplier.hpp>
-#endif
 namespace binfilter {
 
 //------------------------------------------------------------------
@@ -119,7 +99,7 @@ void ScMyTableData::AddColumn()
     nRealCols[aTableCellPos.Column + 1] = nRealCols[aTableCellPos.Column] + nColsPerCol[aTableCellPos.Column];
 }
 
-sal_Int32 ScMyTableData::GetRealCols(const sal_Int32 nIndex, const sal_Bool bIsNormal) const
+sal_Int32 ScMyTableData::GetRealCols(const sal_Int32 nIndex, const sal_Bool /*bIsNormal*/) const
 {
     return (nIndex < 0) ? 0 : nRealCols[nIndex];
 }
@@ -128,7 +108,7 @@ sal_Int32 ScMyTableData::GetChangedCols(const sal_Int32 nFromIndex, const sal_In
 {
     ScMysalIntList::const_iterator i = nChangedCols.begin();
     while ((i != nChangedCols.end()) && ((*i < nToIndex) && !(*i >= nFromIndex)))
-        i++;
+        ++i;
     if (i == nChangedCols.end())
         return -1;
     else
@@ -142,10 +122,7 @@ void ScMyTableData::SetChangedCols(const sal_Int32 nValue)
 {
     ScMysalIntList::iterator i = nChangedCols.begin();
     while ((i != nChangedCols.end()) && (*i < nValue))
-    {
-        sal_Int32 nTemp = *i;
-        i++;
-    }
+        ++i;
     if ((i == nChangedCols.end()) || (*i != nValue))
         nChangedCols.insert(i, nValue);
 }
@@ -154,12 +131,12 @@ void ScMyTableData::SetChangedCols(const sal_Int32 nValue)
 
 ScMyTables::ScMyTables(ScXMLImport& rTempImport)
     : rImport(rTempImport),
-    nTableCount( 0 ),
-    nCurrentSheet( -1 ),
+    aResizeShapes(rTempImport),
+    nCurrentColStylePos(0),
     nCurrentDrawPage( -1 ),
     nCurrentXShapes( -1 ),
-    aResizeShapes(rTempImport),
-    nCurrentColStylePos(0)
+    nTableCount( 0 ),
+    nCurrentSheet( -1 )
 {
     aTableVec.resize(nDefaultTabCount, NULL);
 }
@@ -501,7 +478,7 @@ void ScMyTables::NewColumn(sal_Bool bIsCovered)
                     + LastColSpanned);
             }
         }
-        sal_Int32 nTemp = aTableVec[nTableCount - 1]->GetRealCols(aTableVec[nTableCount - 1]->GetColumn());
+        /*sal_Int32 nTemp =*/ aTableVec[nTableCount - 1]->GetRealCols(aTableVec[nTableCount - 1]->GetColumn());
         if (aTableVec[nTableCount - 1]->GetRealCols(aTableVec[nTableCount - 1]->GetColumn()) > nSpannedCols - 1)
         {
             if ( aTableVec[nTableCount - 1]->GetRow() == 0)
@@ -589,8 +566,8 @@ void ScMyTables::UpdateRowHeights()
     {
         rImport.LockSolarMutex();
         // update automatic row heights
-        sal_Int16 nTableCount(rImport.GetDocument() ? rImport.GetDocument()->GetTableCount() : 0);
-        for (sal_Int16 i = 0; i < nTableCount; i++)
+        sal_Int16 nLclTableCount(rImport.GetDocument() ? rImport.GetDocument()->GetTableCount() : 0);
+        for (sal_Int16 i = 0; i < nLclTableCount; i++)
             ScModelObj::getImplementation(rImport.GetModel())->AdjustRowHeight( 0, MAXROW, i );
         rImport.UnlockSolarMutex();
     }
@@ -735,7 +712,7 @@ void ScMyTables::AddMatrixRange(sal_uInt32 nStartColumn, sal_uInt32 nStartRow, s
     aMatrixRangeList.push_back(aRange);
 }
 
-sal_Bool ScMyTables::IsPartOfMatrix(sal_uInt32 nColumn, sal_uInt32 nRow)
+sal_Bool ScMyTables::IsPartOfMatrix(sal_Int32 nColumn, sal_Int32 nRow)
 {
     sal_Bool bResult(sal_False);
     if (!aMatrixRangeList.empty())
@@ -763,3 +740,5 @@ sal_Bool ScMyTables::IsPartOfMatrix(sal_uInt32 nColumn, sal_uInt32 nRow)
     return bResult;
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
