@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -37,9 +38,7 @@
 #include <comphelper/processfactory.hxx>
 
 
-#ifndef _CONFIG_HXX
 #include <tools/config.hxx>
-#endif
 
 #include <bf_so3/factory.hxx>
 
@@ -62,7 +61,6 @@
 #include <bf_so3/ipenv.hxx>
 #include <bf_so3/protocol.hxx>
 #include "bf_so3/plugin.hxx"
-// #include "bf_so3/applet.hxx"
 #include "bf_so3/soerr.hxx"
 #include <comphelper/classids.hxx>
 #include "insdlg.hxx"
@@ -112,7 +110,6 @@ SoDll::SoDll()
     , pSoBindingFactory( NULL )
     , pContEnvList( NULL )
     , pIPActiveClientList( NULL )
-    , pIPActiveObjectList( NULL )
     , pUIShowIPEnv( NULL )
     , pIEOPDflt( NULL )
     , aSvInterface( 0xB34BB240L, 0x4BD8, 0x101C, 0x8D, 0x86,
@@ -133,7 +130,6 @@ SoDll::~SoDll()
 {
     delete pResMgr;
     delete pIPActiveClientList;
-    delete pIPActiveObjectList;
     delete pContEnvList;
     SvEditObjectProtocol::Imp_DeleteDefault();
     delete pDeathTimer;
@@ -207,35 +203,35 @@ String SvFactory::GetServiceName( const SvGlobalName& rClassName )
     ::rtl::OUString aServiceName;
     if( SvGlobalName(SO3_SC_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Calc.SpreadsheetDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Calc.SpreadsheetDocument" ));
     }
     else if( SvGlobalName(SO3_SW_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Writer.TextDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Writer.TextDocument" ));
     }
     else if( SvGlobalName(SO3_SWWEB_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Writer.WebDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Writer.WebDocument" ));
     }
     else if( SvGlobalName(SO3_SWGLOB_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Writer.GlobalDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Writer.GlobalDocument" ));
     }
     else if( SvGlobalName(SO3_SIMPRESS_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Draw.PresentationDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Draw.PresentationDocument" ));
     }
     else if( SvGlobalName(SO3_SDRAW_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Draw.DrawingDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Draw.DrawingDocument" ));
     }
     else if( SvGlobalName(SO3_SCH_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Chart.ChartDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Chart.ChartDocument" ));
     }
     else if( SvGlobalName(SO3_SM_CLASSID_60) == rClassName )
     {
-        aServiceName = ::rtl::OUString::createFromAscii("com.sun.star.comp.Math.FormulaDocument");
+        aServiceName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Math.FormulaDocument" ));
     }
 
     return aServiceName;
@@ -251,7 +247,7 @@ SvObject* TryCreate( const SvGlobalName& rClassName )
         if ( xDoc.is() )
         {
             com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue > aProps( 1 );
-            aProps[0].Name = ::rtl::OUString::createFromAscii( "SetEmbedded" );
+            aProps[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SetEmbedded" ));
             aProps[0].Value <<= sal_True;
             xDoc->attachResource( ::rtl::OUString(), aProps );
 
@@ -259,7 +255,7 @@ SvObject* TryCreate( const SvGlobalName& rClassName )
             ::com::sun::star::uno::Sequence < sal_Int8 > aSeq( (sal_Int8*) SvGlobalName( SO3_GLOBAL_CLASSID ).GetBytes(), 16 );
             sal_Int64 nHandle = xObj->getSomething( aSeq );
             if ( nHandle )
-                return reinterpret_cast<SvObject*>(sal::static_int_cast<sal_IntPtr>(nHandle)); 
+                return reinterpret_cast<SvObject*>(sal::static_int_cast<sal_IntPtr>(nHandle));
                 // return (SvObject*) (sal_Int32*) nHandle;
         }
     }
@@ -602,34 +598,6 @@ ConvertTo_Impl (* SetupConvertTable_Impl( USHORT * pCount )) [SO3_OFFICE_VERSION
           SOT_FORMATSTR_ID_STARWRITERGLOB_60
         );
 
-#if 0
-        // obselete, because Image has been removed
-        pSoApp->pConvTable[2][0] = ConvertTo_Impl
-        (// StarImage 3.0
-          SvGlobalName( 0xEA60C941L, 0x2C6C, 0x101C, 0x8E, 0x2C, 0x00, 0x00, 0x1B, 0x4C, 0xC7, 0x11 ),
-          SOT_FORMATSTR_ID_STARIMAGE
-        );
-        pSoApp->pConvTable[2][1] = ConvertTo_Impl
-        (// StarImage 4.0
-          SvGlobalName( 0x447BB8A0L, 0x41FB, 0x11D0, 0x89, 0xCA, 0x00, 0x80, 0x29, 0xE4, 0xB0, 0xB1 ),
-          SOT_FORMATSTR_ID_STARIMAGE_40
-        );
-        pSoApp->pConvTable[2][2] = ConvertTo_Impl
-        (// StarImage 5.0
-          SvGlobalName( SO3_SIM_CLASSID_50 ),
-          SOT_FORMATSTR_ID_STARIMAGE_50
-        );
-        pSoApp->pConvTable[2][3] = ConvertTo_Impl
-        (// StarImage 5.0
-          SvGlobalName( SO3_SIM_CLASSID ),
-          SOT_FORMATSTR_ID_STARIMAGE_50
-        );
-        pSoApp->pConvTable[2][4] = ConvertTo_Impl
-        (// StarImage 5.0
-          SvGlobalName( SO3_SIM_CLASSID ),
-          SOT_FORMATSTR_ID_STARIMAGE_50
-        );
-#endif
     }
     *pCount = pSoApp->nConvTableEntries;
     return pSoApp->pConvTable;
@@ -805,7 +773,7 @@ BOOL SvFactory::IsIntern
                     case 2: *pFileFormat = SOFFICE_FILEFORMAT_50; break;
                     case 3: *pFileFormat = SOFFICE_FILEFORMAT_60; break;
                     default:
-                            DBG_ERROR( "unexepected class id" );
+                            OSL_FAIL( "unexepected class id" );
                             break;
                     }
                 }
@@ -834,3 +802,5 @@ SvGlobalName SvFactory::GetServerName( long nStorageFormat )
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
