@@ -55,7 +55,7 @@ sal_Bool GetModifiedDateTimeOfFile( const UniString& rURL,
         ::ucbhelper::Content aTestContent( rURL,
                                 uno::Reference< XCommandEnvironment > ());
         uno::Any aAny = aTestContent.getPropertyValue(
-            OUString::createFromAscii(  "DateModified" ) );
+            OUString( RTL_CONSTASCII_USTRINGPARAM( "DateModified" )) );
         if( aAny.hasValue() )
         {
             bRet = sal_True;
